@@ -1,4 +1,6 @@
 from cacheall.Algorithms.doublylinkedlist import DoublyLinkedList as dll 
+from .verbose import Verbose
+
 # LRU cache class
 class LIFOCache:
 
@@ -7,6 +9,8 @@ class LIFOCache:
         # Initialize all variable
         self.capacity = capacity
         self.map = {}
+        self.verdata=Verbose(verbose)
+        self.verbose=verbose
         self.list=dll()
         self.count = 0
         self.lock=lock
@@ -18,32 +22,25 @@ class LIFOCache:
             if key in self.map:
                 node = self.map[key]
                 result = node.val
-                print('Got the value : {} for the key: {}'.format(result, key))
                 return result
-            print('Did not get any value for the key: {}'.format(key))
-            self.list.printlist()
+            self.verdata.get_data(key,result,self.list.head)
         return -1
 
     # This method works in O(1)
     def set(self, key, value):
         with self.lock:
-            print('going to set the (key, value) : ( {}, {})'.format(key, value))
             if key in self.map:
                 node = self.map[key]
                 node.val = value
             else:
                 if self.count < self.capacity:
-                    
                     self.count += 1
                     self.map[key]=self.list.addToHead(key,value)
-                    # print(self.count)
                 else:
-                    # print(self.list.tail.key)
                     del self.map[self.list.head.key]
                     self.list.deleteNode(self.list.head)
                     self.map[key]=self.list.addToHead(key,value)
-        
-            self.list.printlist()
+            self.verdata.set_data(key,value,self.list.head)
 
 
 
